function p = effdfCorr(r,df,tail)

% function p = calculate_p(r,df,tail).
% Returns the significance value of an observed correlation.
% The effective degrees of freedom were estimated using the approach described 
% by Pyper and Peterman (1998)

% R = correlation value 
% DF = effective degrees of freedom
% TAIL = 1 for one-tailed, 2 for two-tailed distribution. Default = 2
%  
% examples
% p = calculate_p(.7,98);
% p = calculate_p(-.4,54,1);

if nargin < 3
    tail = 2;
end

% r to Z:
% r isconverted to respective Z-score maps using Fisher's Z transformation,	
% normalized	by	the	factor	1/sqrt(df-3).
% where	df represents the estimated number of effective degrees of freedom. 

z = atanh(r);
corrected_z = z*(sqrt(df-3));
%  Z to p
if tail==1
    p = normcdf(corrected_z);
else
    p = 2*normcdf(-abs(corrected_z));
end

end
